@@ -45,7 +45,7 @@ static GtkWidget *create_entry (GdauiEntryWrapper *mgwrap);
 static void       real_set_value (GdauiEntryWrapper *mgwrap, const GValue *value);
 static GValue    *real_get_value (GdauiEntryWrapper *mgwrap);
 static void       connect_signals(GdauiEntryWrapper *mgwrap, GCallback modify_cb, GCallback activate_cb);
-static gboolean   expand_in_layout (GdauiEntryWrapper *mgwrap);
+static gboolean   can_expand (GdauiEntryWrapper *mgwrap, gboolean horiz);
 static void       set_editable (GdauiEntryWrapper *mgwrap, gboolean editable);
 static gboolean   value_is_equal_to (GdauiEntryWrapper *mgwrap, const GValue *value);
 static gboolean   value_is_null (GdauiEntryWrapper *mgwrap);
@@ -83,7 +83,8 @@ gdaui_entry_pict_get_type (void)
 			NULL,
 			sizeof (GdauiEntryPict),
 			0,
-			(GInstanceInitFunc) gdaui_entry_pict_init
+			(GInstanceInitFunc) gdaui_entry_pict_init,
+			0
 		};
 		
 		type = g_type_register_static (GDAUI_TYPE_ENTRY_WRAPPER, "GdauiEntryPict", &info, 0);
@@ -105,7 +106,7 @@ gdaui_entry_pict_class_init (GdauiEntryPictClass * class)
 	GDAUI_ENTRY_WRAPPER_CLASS (class)->real_set_value = real_set_value;
 	GDAUI_ENTRY_WRAPPER_CLASS (class)->real_get_value = real_get_value;
 	GDAUI_ENTRY_WRAPPER_CLASS (class)->connect_signals = connect_signals;
-	GDAUI_ENTRY_WRAPPER_CLASS (class)->expand_in_layout = expand_in_layout;
+	GDAUI_ENTRY_WRAPPER_CLASS (class)->can_expand = can_expand;
 	GDAUI_ENTRY_WRAPPER_CLASS (class)->set_editable = set_editable;
 	GDAUI_ENTRY_WRAPPER_CLASS (class)->value_is_equal_to = value_is_equal_to;
 	GDAUI_ENTRY_WRAPPER_CLASS (class)->value_is_null = value_is_null;
@@ -211,7 +212,7 @@ static gboolean event_cb (GtkWidget *button, GdkEvent *event, GdauiEntryPict *mg
 static void size_allocate_cb (GtkWidget *wid, GtkAllocation *allocation, GdauiEntryPict *mgpict);
 
 static void
-realize_cb (GdauiEntryPict *mgpict, GdauiEntryWrapper *mgwrap)
+realize_cb (GdauiEntryPict *mgpict, G_GNUC_UNUSED GdauiEntryWrapper *mgwrap)
 {
 	display_image (mgpict, NULL, NULL, NULL);
 }
@@ -264,7 +265,7 @@ create_entry (GdauiEntryWrapper *mgwrap)
 }
 
 static void
-size_allocate_cb (GtkWidget *wid, GtkAllocation *allocation, GdauiEntryPict *mgpict)
+size_allocate_cb (G_GNUC_UNUSED GtkWidget *wid, GtkAllocation *allocation, GdauiEntryPict *mgpict)
 {
 	if ((mgpict->priv->size.width != allocation->width) ||
 	    (mgpict->priv->size.height != allocation->height)) {
@@ -440,13 +441,14 @@ real_get_value (GdauiEntryWrapper *mgwrap)
 }
 
 static void
-connect_signals(GdauiEntryWrapper *mgwrap, GCallback modify_cb, GCallback activate_cb)
+connect_signals(G_GNUC_UNUSED GdauiEntryWrapper *mgwrap, G_GNUC_UNUSED GCallback modify_cb,
+		G_GNUC_UNUSED GCallback activate_cb)
 {
-	/* doe nothing because we manullay call gdaui_entry_wrapper_contents_changed() */
+	/* do nothing because we manually call gdaui_entry_wrapper_contents_changed() */
 }
 
 static gboolean
-expand_in_layout (GdauiEntryWrapper *mgwrap)
+can_expand (G_GNUC_UNUSED GdauiEntryWrapper *mgwrap, G_GNUC_UNUSED gboolean horiz)
 {
 	return TRUE;
 }
@@ -484,7 +486,8 @@ value_is_equal_to (GdauiEntryWrapper *mgwrap, const GValue *value)
 			blob = (GdaBlob*) gda_value_get_blob ((GValue *) value);
 			g_assert (blob);
 			bin = (GdaBinary *) blob;
-			if (blob->op) 
+			if (blob->op &&
+			    (bin->binary_length != gda_blob_op_get_length (blob->op)))
 				gda_blob_op_read_all (blob->op, blob);
 			if (mgpict->priv->bindata.data)
 				return !memcmp (bin->data, mgpict->priv->bindata.data, MIN (mgpict->priv->bindata.data_length, bin->binary_length));
