@@ -31,8 +31,6 @@
 #include "gdaui-entry-text.h"
 #include "gdaui-entry-pict.h"
 #include "gdaui-data-cell-renderer-pict.h"
-#include "gdaui-entry-cgrid.h"
-#include "gdaui-data-cell-renderer-cgrid.h"
 
 #ifdef HAVE_LIBGCRYPT
 #include "gdaui-entry-password.h"
@@ -56,8 +54,6 @@ static GdauiDataEntry *plugin_entry_cidr_create_func (GdaDataHandler *handler, G
 static GdauiDataEntry *plugin_entry_text_create_func (GdaDataHandler *handler, GType type, const gchar *options);
 static GdauiDataEntry *plugin_entry_pict_create_func (GdaDataHandler *handler, GType type, const gchar *options);
 static GtkCellRenderer  *plugin_cell_renderer_pict_create_func (GdaDataHandler *handler, GType type, const gchar *options);
-static GdauiDataEntry *plugin_entry_cgrid_create_func (GdaDataHandler *handler, GType type, const gchar *options);
-static GtkCellRenderer  *plugin_cell_renderer_cgrid_create_func (GdaDataHandler *handler, GType type, const gchar *options);
 
 #ifdef HAVE_LIBGCRYPT
 static GdauiDataEntry *plugin_entry_password_create_func (GdaDataHandler *handler, GType type, const gchar *options);
@@ -276,7 +272,7 @@ plugin_entry_filesel_create_func (GdaDataHandler *handler, GType type, const gch
 }
 
 static GdauiDataEntry *
-plugin_entry_cidr_create_func (GdaDataHandler *handler, GType type, const gchar *options)
+plugin_entry_cidr_create_func (GdaDataHandler *handler, GType type, G_GNUC_UNUSED const gchar *options)
 {
 	return (GdauiDataEntry *) gdaui_entry_cidr_new (handler, type);
 }
@@ -299,18 +295,6 @@ plugin_cell_renderer_pict_create_func (GdaDataHandler *handler, GType type, cons
 	return gdaui_data_cell_renderer_pict_new (handler, type, options);
 }
 
-static GdauiDataEntry *
-plugin_entry_cgrid_create_func (GdaDataHandler *handler, GType type, const gchar *options)
-{
-	return (GdauiDataEntry *) gdaui_entry_cgrid_new (handler, type, options);
-}
-
-static GtkCellRenderer *
-plugin_cell_renderer_cgrid_create_func (GdaDataHandler *handler, GType type, const gchar *options)
-{
-	return (GtkCellRenderer *) gdaui_data_cell_renderer_cgrid_new (handler, type, options);
-}
-
 #ifdef HAVE_LIBGCRYPT
 static GdauiDataEntry *
 plugin_entry_password_create_func (GdaDataHandler *handler, GType type, const gchar *options)
