@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999 - 2009 The GNOME Foundation.
+ * Copyright (C) 1999 - 2010 The GNOME Foundation.
  *
  * AUTHORS:
  * 	Rodrigo Moya <rodrigo@gnome-db.org>
@@ -48,7 +48,7 @@ GHashTable *gdaui_plugins_hash = NULL; /* key = plugin name, value = GdauiPlugin
 
 
 /**
- * gdaui_init
+ * gdaui_init:
  *
  * Initialization of the libgda-ui library, must be called before any usage of the library.
  *
@@ -89,7 +89,7 @@ gdaui_init (void)
 }
 
 /**
- * gdaui_new_data_entry
+ * gdaui_new_data_entry:
  * @type: a #GType
  * @plugin_name: the name of an entry plugin, or %NULL
  *
@@ -100,7 +100,7 @@ gdaui_init (void)
  * @plugin_name format is interpreted as two parts: &lt;plugin name&gt;:&lt;plugin options&gt;, and
  * if the plugins has no option, then the ":&lt;plugin options&gt;" part may be omitted.
  * 
- * Returns: a new #GdauiDataEntry widget, _NEVER_ %NULL
+ * Returns: (transfer full): a new #GdauiDataEntry widget, _NEVER_ %NULL
  */
 GdauiDataEntry *
 gdaui_new_data_entry (GType type, const gchar *plugin_name)
@@ -236,7 +236,7 @@ _gdaui_new_cell_renderer (GType type, const gchar *plugin_name)
 }
 
 /**
- * gdaui_plugin_declare
+ * gdaui_plugin_declare:
  * @plugin: a pointer to a structure filled to describe the new plugin
  *
  * Adds a new plugin which will be used by the forms and grids. The new plugin, as
@@ -526,19 +526,20 @@ init_plugins_hash (void)
 }
 
 static GdauiDataEntry *
-entry_none_create_func (GdaDataHandler *handler, GType type, const gchar *options)
+entry_none_create_func (G_GNUC_UNUSED GdaDataHandler *handler, GType type, G_GNUC_UNUSED const gchar *options)
 {
 	return (GdauiDataEntry *) gdaui_entry_none_new (type);
 }
 
 static GdauiDataEntry *
-entry_boolean_create_func (GdaDataHandler *handler, GType type, const gchar *options)
+entry_boolean_create_func (GdaDataHandler *handler, G_GNUC_UNUSED GType type,
+			   G_GNUC_UNUSED const gchar *options)
 {
 	return (GdauiDataEntry *) gdaui_entry_boolean_new (handler, G_TYPE_BOOLEAN);
 }
 
 static GdauiDataEntry *
-entry_bin_create_func (GdaDataHandler *handler, GType type, const gchar *options)
+entry_bin_create_func (GdaDataHandler *handler, GType type, G_GNUC_UNUSED const gchar *options)
 {
 	return (GdauiDataEntry *) gdaui_entry_bin_new (handler, type);
 }
@@ -556,19 +557,20 @@ entry_number_create_func (GdaDataHandler *handler, GType type, const gchar *opti
 }
 
 static GdauiDataEntry *
-entry_time_create_func (GdaDataHandler *handler, GType type, const gchar *options)
+entry_time_create_func (GdaDataHandler *handler, G_GNUC_UNUSED GType type, G_GNUC_UNUSED const gchar *options)
 {
 	return (GdauiDataEntry *) gdaui_entry_time_new (handler);
 }
 
 static GdauiDataEntry *
-entry_timestamp_create_func (GdaDataHandler *handler, GType type, const gchar *options)
+entry_timestamp_create_func (GdaDataHandler *handler, G_GNUC_UNUSED GType type,
+			     G_GNUC_UNUSED const gchar *options)
 {
 	return (GdauiDataEntry *) gdaui_entry_timestamp_new (handler);
 }
 
 static GdauiDataEntry *
-entry_date_create_func (GdaDataHandler *handler, GType type, const gchar *options)
+entry_date_create_func (GdaDataHandler *handler, G_GNUC_UNUSED GType type, G_GNUC_UNUSED const gchar *options)
 {
 	return (GdauiDataEntry *) gdaui_entry_date_new (handler);
 }
@@ -580,13 +582,14 @@ cell_textual_create_func (GdaDataHandler *handler, GType type, const gchar *opti
 }
 
 static GtkCellRenderer *
-cell_boolean_create_func (GdaDataHandler *handler, GType type, const gchar *options)
+cell_boolean_create_func (GdaDataHandler *handler, G_GNUC_UNUSED GType type,
+			  G_GNUC_UNUSED const gchar *options)
 {
 	return gdaui_data_cell_renderer_boolean_new (handler, G_TYPE_BOOLEAN);
 }
 
 static GtkCellRenderer *
-cell_bin_create_func (GdaDataHandler *handler, GType type, const gchar *options)
+cell_bin_create_func (GdaDataHandler *handler, GType type, G_GNUC_UNUSED const gchar *options)
 {
 	return gdaui_data_cell_renderer_bin_new (handler, type);
 }
