@@ -100,7 +100,8 @@ gda_meta_struct_get_type (void) {
 			NULL,
 			sizeof (GdaMetaStruct),
 			0,
-			(GInstanceInitFunc) gda_meta_struct_init
+			(GInstanceInitFunc) gda_meta_struct_init,
+			0
 		};
 		
 		g_static_mutex_lock (&registering);
@@ -241,6 +242,7 @@ gda_meta_struct_set_property (GObject *object,
 			mstruct->priv->features = g_value_get_uint (value);
 			break;
 		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
 		}
 	}
@@ -264,20 +266,21 @@ gda_meta_struct_get_property (GObject *object,
 			g_value_set_uint (value, mstruct->priv->features);
 			break;
 		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
 		}
 	}
 }
 
 static void
-meta_store_changed_cb (GdaMetaStore *store, GSList *changes, GdaMetaStruct *mstruct)
+meta_store_changed_cb (GdaMetaStore *store, G_GNUC_UNUSED GSList *changes, GdaMetaStruct *mstruct)
 {
 	/* for now we mark ALL the db objects as outdated */
 	meta_store_reset_cb (store, mstruct);
 }
 
 static void
-meta_store_reset_cb (GdaMetaStore *store, GdaMetaStruct *mstruct)
+meta_store_reset_cb (G_GNUC_UNUSED GdaMetaStore *store, GdaMetaStruct *mstruct)
 {
 	/* mark ALL the db objects as outdated */
 	GSList *list;
@@ -1450,7 +1453,8 @@ db_object_sort_func (GdaMetaDbObject *dbo1, GdaMetaDbObject *dbo2)
  * Returns: TRUE if no error occurred
  */ 
 gboolean
-gda_meta_struct_sort_db_objects (GdaMetaStruct *mstruct, GdaMetaSortType sort_type, GError **error)
+gda_meta_struct_sort_db_objects (GdaMetaStruct *mstruct, GdaMetaSortType sort_type,
+				 G_GNUC_UNUSED GError **error)
 {
 	GSList *pass_list;
 	GSList *ordered_list = NULL;
@@ -1606,7 +1610,7 @@ gda_meta_struct_get_db_object (GdaMetaStruct *mstruct, const GValue *catalog, co
 }
 
 /**
- * gda_meta_struct_get_table_column
+ * gda_meta_struct_get_table_column: (skip):
  * @mstruct: a #GdaMetaStruct object
  * @table: the #GdaMetaTable structure to find the column for
  * @col_name: the name of the column to find (as a G_TYPE_STRING GValue)
@@ -1645,7 +1649,7 @@ gda_meta_struct_get_table_column (GdaMetaStruct *mstruct, GdaMetaTable *table, c
  * Returns: (transfer full): a new string, or %NULL if an error occurred.
  */
 gchar *
-gda_meta_struct_dump_as_graph (GdaMetaStruct *mstruct, GdaMetaGraphInfo info, GError **error)
+gda_meta_struct_dump_as_graph (GdaMetaStruct *mstruct, GdaMetaGraphInfo info, G_GNUC_UNUSED GError **error)
 {
 	GString *string;
 	gchar *result;
@@ -2238,7 +2242,7 @@ copyerror:
  * @error: (allow-none): a place to store errors, or %NULL
  *
  * Adds @dbo to the database objects known to @mstruct. In any case (whether an error occured or not)
- * @dbo's responsibility is then transferred to @smtruct and should
+ * @dbo's ownership is then transferred to @smtruct and should
  * not be used after calling this function (it may have been destroyed). If you need a pointer to the #GdaMetaDbObject
  * for a database object, use gda_meta_struct_get_db_object().
  *
@@ -2340,8 +2344,8 @@ gda_meta_table_column_set_attribute (GdaMetaTableColumn *tcol, const gchar *attr
 /**
  * gda_meta_table_column_foreach_attribute:
  * @tcol: a #GdaMetaTableColumn
- * @func: a #GdaAttributesManagerFunc function
- * @data: user data to be passed as last argument of @func each time it is called
+ * @func: (scope call): a #GdaAttributesManagerFunc function
+ * @data: (closure): user data to be passed as last argument of @func each time it is called
  *
  * Calls @func for each attribute set to tcol
  */
