@@ -117,6 +117,7 @@ GType                      gda_server_operation_get_type                (void) G
 GdaServerOperation        *gda_server_operation_new                     (GdaServerOperationType op_type, const gchar *xml_file);
 GdaServerOperationType     gda_server_operation_get_op_type             (GdaServerOperation *op);
 const gchar               *gda_server_operation_op_type_to_string       (GdaServerOperationType type);
+GdaServerOperationType     gda_server_operation_string_to_op_type       (const gchar *str);
 GdaServerOperationNode    *gda_server_operation_get_node_info           (GdaServerOperation *op, const gchar *path_format, ...);
 
 const GValue              *gda_server_operation_get_value_at            (GdaServerOperation *op, const gchar *path_format, ...);
@@ -142,7 +143,7 @@ guint                      gda_server_operation_get_sequence_max_size   (GdaServ
 guint                      gda_server_operation_get_sequence_min_size   (GdaServerOperation *op, const gchar *path);
 gchar                    **gda_server_operation_get_sequence_item_names (GdaServerOperation *op, const gchar *path); 
 
-guint                      gda_server_operation_add_item_to_sequence    (GdaServerOperation *op, const gchar *path);
+guint                      gda_server_operation_add_item_to_sequence    (GdaServerOperation *op, const gchar *seq_path);
 gboolean                   gda_server_operation_del_item_from_sequence  (GdaServerOperation *op, const gchar *item_path);
 
 gboolean                   gda_server_operation_is_valid                (GdaServerOperation *op, const gchar *xml_file, GError **error);
