@@ -158,7 +158,7 @@ gda_server_provider_handler_info_free (GdaServerProviderHandlerInfo *info)
 
 static void
 gda_server_provider_init (GdaServerProvider *provider,
-			  GdaServerProviderClass *klass)
+			  G_GNUC_UNUSED GdaServerProviderClass *klass)
 {
 	g_return_if_fail (GDA_IS_SERVER_PROVIDER (provider));
 
@@ -206,7 +206,8 @@ gda_server_provider_get_type (void)
 			NULL,
 			sizeof (GdaServerProvider),
 			0,
-			(GInstanceInitFunc) gda_server_provider_init
+			(GInstanceInitFunc) gda_server_provider_init,
+			0
 		};
 		g_static_mutex_lock (&registering);
 		if (type == 0)
@@ -220,7 +221,7 @@ gda_server_provider_get_type (void)
 static void
 gda_server_provider_set_property (GObject *object,
 				  guint param_id,
-				  const GValue *value,
+				  G_GNUC_UNUSED const GValue *value,
 				  GParamSpec *pspec) {
         GdaServerProvider *prov;
 
@@ -228,7 +229,8 @@ gda_server_provider_set_property (GObject *object,
         if (prov->priv) {
                 switch (param_id) {
 		default:
-			g_assert_not_reached ();
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
 		}
 	}
 }
@@ -236,7 +238,7 @@ gda_server_provider_set_property (GObject *object,
 static void
 gda_server_provider_get_property (GObject *object,
 				  guint param_id,
-				  GValue *value,
+				  G_GNUC_UNUSED GValue *value,
 				  GParamSpec *pspec) {
         GdaServerProvider *prov;
 
@@ -244,7 +246,8 @@ gda_server_provider_get_property (GObject *object,
         if (prov->priv) {
                 switch (param_id) {
 		default:
-			g_assert_not_reached ();
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
 		}
 	}
 }
@@ -345,13 +348,13 @@ typedef struct {
 static OpReq op_req_CREATE_DB [] = {
 	{"/DB_DEF_P",               GDA_SERVER_OPERATION_NODE_PARAMLIST, 0},
 	{"/DB_DEF_P/DB_NAME",       GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 static OpReq op_req_DROP_DB [] = {
 	{"/DB_DESC_P",               GDA_SERVER_OPERATION_NODE_PARAMLIST, 0},
 	{"/DB_DESC_P/DB_NAME",       GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 static OpReq op_req_CREATE_TABLE [] = {
@@ -360,26 +363,26 @@ static OpReq op_req_CREATE_TABLE [] = {
 	{"/FIELDS_A",                  GDA_SERVER_OPERATION_NODE_DATA_MODEL, 0},
 	{"/FIELDS_A/@COLUMN_NAME",     GDA_SERVER_OPERATION_NODE_DATA_MODEL_COLUMN, G_TYPE_STRING},
 	{"/FIELDS_A/@COLUMN_TYPE",     GDA_SERVER_OPERATION_NODE_DATA_MODEL_COLUMN, G_TYPE_STRING},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 static OpReq op_req_DROP_TABLE [] = {
 	{"/TABLE_DESC_P/TABLE_NAME",   GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 static OpReq op_req_RENAME_TABLE [] = {
 	{"/TABLE_DESC_P",                  GDA_SERVER_OPERATION_NODE_PARAMLIST, 0},
 	{"/TABLE_DESC_P/TABLE_NAME",       GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
 	{"/TABLE_DESC_P/TABLE_NEW_NAME",   GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 static OpReq op_req_COMMENT_TABLE [] = {
 	{"/TABLE_DESC_P",               GDA_SERVER_OPERATION_NODE_PARAMLIST, 0},
 	{"/TABLE_DESC_P/TABLE_NAME",    GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
 	{"/TABLE_DESC_P/TABLE_COMMENT", GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 static OpReq op_req_ADD_COLUMN [] = {
@@ -387,14 +390,14 @@ static OpReq op_req_ADD_COLUMN [] = {
 	{"/COLUMN_DEF_P/TABLE_NAME",    GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
 	{"/COLUMN_DEF_P/COLUMN_NAME",   GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
 	{"/COLUMN_DEF_P/COLUMN_TYPE",   GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 static OpReq op_req_DROP_COLUMN [] = {
 	{"/COLUMN_DESC_P",               GDA_SERVER_OPERATION_NODE_PARAMLIST, 0},
 	{"/COLUMN_DESC_P/TABLE_NAME",    GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
 	{"/COLUMN_DESC_P/COLUMN_NAME",   GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 static OpReq op_req_COMMENT_COLUMN [] = {
@@ -402,37 +405,37 @@ static OpReq op_req_COMMENT_COLUMN [] = {
 	{"/COLUMN_DESC_P/TABLE_NAME",     GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
 	{"/COLUMN_DESC_P/COLUMN_NAME",    GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
 	{"/COLUMN_DESC_P/COLUMN_COMMENT", GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 static OpReq op_req_CREATE_INDEX [] = {
 	{"/INDEX_DEF_P/INDEX_NAME",       GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
 	{"/INDEX_DEF_P/INDEX_ON_TABLE",   GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
 	{"/INDEX_FIELDS_S",               GDA_SERVER_OPERATION_NODE_SEQUENCE, 0},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 static OpReq op_req_DROP_INDEX [] = {
 	{"/INDEX_DESC_P/INDEX_NAME",   GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 static OpReq op_req_CREATE_VIEW [] = {
 	{"/VIEW_DEF_P",               GDA_SERVER_OPERATION_NODE_PARAMLIST, 0},
 	{"/VIEW_DEF_P/VIEW_NAME",     GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
 	{"/VIEW_DEF_P/VIEW_DEF",      GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 static OpReq op_req_DROP_VIEW [] = {
 	{"/VIEW_DESC_P/VIEW_NAME",   GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 static OpReq op_req_CREATE_USER [] = {
 	{"/USER_DEF_P",               GDA_SERVER_OPERATION_NODE_PARAMLIST, 0},
 	{"/USER_DEF_P/USER_NAME",     GDA_SERVER_OPERATION_NODE_PARAM, G_TYPE_STRING},
-	{NULL}
+	{NULL, 0, 0}
 };
 
 
@@ -451,7 +454,7 @@ static OpReq op_req_CREATE_USER [] = {
  *  <listitem>named values which may change the contents of the GdaServerOperation, see <link linkend="gda-server-op-information-std">this section</link> for more information</listitem>
  * </itemizedlist>
  *
- * Returns: (transfer full): a new #GdaServerOperation object, or %NULL in the provider does not support the @type type of operation or if an error occurred
+ * Returns: (transfer full) (allow-none): a new #GdaServerOperation object, or %NULL in the provider does not support the @type type of operation or if an error occurred
  */
 GdaServerOperation *
 gda_server_provider_create_operation (GdaServerProvider *provider, GdaConnection *cnc, 
@@ -559,7 +562,7 @@ gda_server_provider_create_operation (GdaServerProvider *provider, GdaConnection
  * This function's purpose is mainly informative to get the actual SQL code which would be executed to perform
  * the operation; to actually perform the operation, use gda_server_provider_perform_operation().
  *
- * Returns: (transfer full): a new string, or %NULL if an error occurred or operation cannot be rendered as SQL.
+ * Returns: (transfer full) (allow-none): a new string, or %NULL if an error occurred or operation cannot be rendered as SQL.
  */
 gchar *
 gda_server_provider_render_operation (GdaServerProvider *provider, GdaConnection *cnc, 
@@ -734,7 +737,7 @@ gda_server_provider_get_data_handler_dbms (GdaServerProvider *provider, GdaConne
 /**
  * gda_server_provider_get_default_dbms_type:
  * @provider: a server provider.
- * @cnc:(allow-none):  a #GdaConnection object or %NULL
+ * @cnc: (allow-none):  a #GdaConnection object or %NULL
  * @type: a #GType value type
  *
  * Get the name of the most common data type which has @type type.
@@ -743,7 +746,7 @@ gda_server_provider_get_data_handler_dbms (GdaServerProvider *provider, GdaConne
  * there is no DBMS data type which could contain data of the @g_type type (for example %NULL may be
  * returned if a DBMS has integers only up to 4 bytes and a G_TYPE_INT64 is requested).
  *
- * Returns: (transfer none): the name of the DBMS type, or %NULL
+ * Returns: (transfer none) (allow-none): the name of the DBMS type, or %NULL
  */
 const gchar *
 gda_server_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConnection *cnc, GType type)
@@ -795,7 +798,7 @@ gda_server_provider_string_to_value (GdaServerProvider *provider,  GdaConnection
 {
 	GValue *retval = NULL;
 	GdaDataHandler *dh;
-	gint i;
+	gsize i;
 
 	g_return_val_if_fail (GDA_IS_SERVER_PROVIDER (provider), NULL);
 	g_return_val_if_fail (!cnc || GDA_IS_CONNECTION (cnc), NULL);
