@@ -70,7 +70,7 @@ gda_vconnection_data_model_class_init (GdaVconnectionDataModelClass *klass)
 }
 
 static void
-gda_vconnection_data_model_init (GdaVconnectionDataModel *cnc, GdaVconnectionDataModelClass *klass)
+gda_vconnection_data_model_init (GdaVconnectionDataModel *cnc, G_GNUC_UNUSED GdaVconnectionDataModelClass *klass)
 {
 	cnc->priv = g_new (GdaVconnectionDataModelPrivate, 1);
 	cnc->priv->table_data_list = NULL;
@@ -114,7 +114,8 @@ gda_vconnection_data_model_get_type (void)
 				NULL, NULL,
 				sizeof (GdaVconnectionDataModel),
 				0,
-				(GInstanceInitFunc) gda_vconnection_data_model_init
+				(GInstanceInitFunc) gda_vconnection_data_model_init,
+				0
 			};
 			
 		g_static_mutex_lock (&registering);
@@ -130,7 +131,7 @@ gda_vconnection_data_model_get_type (void)
 static void
 gda_vconnection_data_model_set_property (GObject *object,
 					 guint param_id,
-					 const GValue *value,
+					 G_GNUC_UNUSED const GValue *value,
 					 GParamSpec *pspec)
 {
         GdaVconnectionDataModel *cnc;
@@ -139,6 +140,7 @@ gda_vconnection_data_model_set_property (GObject *object,
         if (cnc->priv) {
                 switch (param_id) {
 		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
                 }
         }
@@ -147,7 +149,7 @@ gda_vconnection_data_model_set_property (GObject *object,
 static void
 gda_vconnection_data_model_get_property (GObject *object,
 					 guint param_id,
-					 GValue *value,
+					 G_GNUC_UNUSED GValue *value,
 					 GParamSpec *pspec)
 {
         GdaVconnectionDataModel *cnc;
@@ -156,6 +158,7 @@ gda_vconnection_data_model_get_property (GObject *object,
         if (cnc->priv) {
 		switch (param_id) {
 		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
 		}
         }
@@ -230,7 +233,7 @@ gda_vconnection_data_model_add (GdaVconnectionDataModel *cnc, GdaVconnectionData
 	g_return_val_if_fail (GDA_IS_VCONNECTION_DATA_MODEL (cnc), FALSE);
 	g_return_val_if_fail (table_name && *table_name, FALSE);
 	g_return_val_if_fail (spec, FALSE);
-	g_return_val_if_fail (spec->data_model || (spec->create_columns_func && spec->create_model_func), FALSE);
+	g_return_val_if_fail (spec->data_model || (spec->create_columns_func && (spec->create_model_func || spec->create_filtered_model_func)), FALSE);
 	if (spec->data_model)
 		g_return_val_if_fail (GDA_IS_DATA_MODEL (spec->data_model), FALSE);
 
