@@ -92,7 +92,11 @@ jni_wrapper_create_vm (JavaVM **out_jvm, CreateJavaVMFunc create_func,
 	}
 
 	gchar * confdir;
-	confdir = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (), ".libgda", NULL);
+	confdir = g_build_path (G_DIR_SEPARATOR_S, g_get_user_data_dir (), "libgda", NULL);
+	if (!g_file_test (confdir, G_FILE_TEST_EXISTS)) {
+		g_free (confdir);
+		confdir = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir (), ".libgda", NULL);
+	}
 	classpath = locate_jars (classpath, confdir);
 	g_free (confdir);
 
@@ -155,21 +159,21 @@ jni_wrapper_create_vm (JavaVM **out_jvm, CreateJavaVMFunc create_func,
 	jclass klass;
 	klass = jni_wrapper_class_get (env, "java/lang/Throwable", NULL);
 	if (!klass) 
-		g_warning ("Error loading '%s' class (error messages won't be detailled)",
+		g_warning ("Error loading '%s' class (error messages won't be detailed)",
 			   "java.lang.Throwable");
 	else {
 		get_message_method = jni_wrapper_method_create (env, klass, 
 								"getMessage", "()Ljava/lang/String;", 
 								FALSE, NULL);
 		if (!get_message_method)
-			g_warning ("Error loading '%s' method (error messages won't be detailled)",
+			g_warning ("Error loading '%s' method (error messages won't be detailed)",
 				   "java.lang.Throwable.getMessage");
 		(*env)->DeleteGlobalRef (env, klass);
 	}
 
 	klass = jni_wrapper_class_get (env, "java/sql/SQLException", NULL);
 	if (!klass) 
-		g_warning ("Error loading '%s' class (error messages won't be detailled)",
+		g_warning ("Error loading '%s' class (error messages won't be detailed)",
 			   "java.sql.SqlException");
 	else {
 		SQLException__class = klass;
@@ -177,7 +181,7 @@ jni_wrapper_create_vm (JavaVM **out_jvm, CreateJavaVMFunc create_func,
 								   "getErrorCode", "()I", 
 								   FALSE, NULL);
 		if (!get_error_code_method)
-			g_warning ("Error loading '%s' method (error messages won't be detailled)",
+			g_warning ("Error loading '%s' method (error messages won't be detailed)",
 				   "java.SQLException.getErrorCode");
 
 		get_sql_state_method = jni_wrapper_method_create (env, SQLException__class, 
@@ -185,7 +189,7 @@ jni_wrapper_create_vm (JavaVM **out_jvm, CreateJavaVMFunc create_func,
 								  FALSE, NULL);
 
 		if (!get_sql_state_method)
-			g_warning ("Error loading '%s' method (error messages won't be detailled)",
+			g_warning ("Error loading '%s' method (error messages won't be detailed)",
 				   "java.SQLException.getSQLState");
 	}
 
