@@ -100,7 +100,7 @@ enum
  * Object init and finalize
  */
 static void
-gda_postgres_recordset_init (GdaPostgresRecordset *recset, GdaPostgresRecordsetClass *klass)
+gda_postgres_recordset_init (GdaPostgresRecordset *recset, G_GNUC_UNUSED GdaPostgresRecordsetClass *klass)
 {
 	g_return_if_fail (GDA_IS_POSTGRES_RECORDSET (recset));
 	recset->priv = g_new0 (GdaPostgresRecordsetPrivate, 1);
@@ -187,8 +187,9 @@ gda_postgres_recordset_set_property (GObject *object,
                 case PROP_CHUNCK_SIZE:
                         model->priv->chunk_size = g_value_get_int (value);
                         break;
-                default:
-                        break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
                 }
         }
 }
@@ -208,8 +209,9 @@ gda_postgres_recordset_get_property (GObject *object,
                 case PROP_CHUNCKS_READ:
                         g_value_set_int (value, model->priv->chunks_read);
                         break;
-                default:
-                        break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
                 }
         }
 }
@@ -234,7 +236,8 @@ gda_postgres_recordset_get_type (void)
 			NULL,
 			sizeof (GdaPostgresRecordset),
 			0,
-			(GInstanceInitFunc) gda_postgres_recordset_init
+			(GInstanceInitFunc) gda_postgres_recordset_init,
+			0
 		};
 		g_static_mutex_lock (&registering);
 		if (type == 0)
@@ -599,7 +602,8 @@ make_point (GdaGeometricPoint *point, const gchar *value)
 }
 
 static void
-set_value (GdaConnection *cnc, GdaRow *row, GValue *value, GType type, const gchar *thevalue, gint length, GError **error)
+set_value (GdaConnection *cnc, GdaRow *row, GValue *value, GType type, const gchar *thevalue,
+	   G_GNUC_UNUSED gint length, GError **error)
 {
 	gda_value_reset_with_type (value, type);
 
