@@ -98,7 +98,8 @@ auth_dialog_get_type (void)
 			NULL,
 			sizeof (AuthDialog),
 			0,
-			(GInstanceInitFunc) auth_dialog_init
+			(GInstanceInitFunc) auth_dialog_init,
+			0
 		};
 		
 		g_static_mutex_lock (&registering);
@@ -135,7 +136,7 @@ auth_contents_changed_cb (GdauiAuth *auth, gboolean is_valid, AuthDialog *dialog
 static void
 update_ad_auth (AuthData *ad)
 {
-	if (ad->cncinfo.auth_string) {
+	if (ad->auth_widget && ad->cncinfo.auth_string) {
 		/* split array in a list of named parameters, and for each parameter value, 
 		 * set the correcponding parameter in @dset */
 		GdaSet *dset;
@@ -174,7 +175,7 @@ update_ad_auth (AuthData *ad)
   * Update the auth part
   */
 static void
-dsn_changed_cb (GdaConfig *config, GdaDsnInfo *info, AuthDialog *dialog)
+dsn_changed_cb (G_GNUC_UNUSED GdaConfig *config, GdaDsnInfo *info, AuthDialog *dialog)
 {
 	GSList *list;
 	if (!info || !info->name) /* should not happen */
