@@ -28,7 +28,7 @@
 #include "browser-canvas-column.h"
 #include "browser-canvas-fkey.h"
 #include "../common/objects-cloud.h"
-#include "../common/popup-container.h"
+#include <libgda-ui/internal/popup-container.h>
 
 static void browser_canvas_db_relations_class_init (BrowserCanvasDbRelationsClass *class);
 static void browser_canvas_db_relations_init       (BrowserCanvasDbRelations *canvas);
@@ -84,7 +84,8 @@ browser_canvas_db_relations_get_type (void)
 			NULL,
 			sizeof (BrowserCanvasDbRelations),
 			0,
-			(GInstanceInitFunc) browser_canvas_db_relations_init
+			(GInstanceInitFunc) browser_canvas_db_relations_init,
+			0
 		};		
 
 		type = g_type_register_static (TYPE_BROWSER_CANVAS, "BrowserCanvasDbRelations", &info, 0);
@@ -177,6 +178,9 @@ browser_canvas_db_relations_set_property (GObject *object,
 				objects_cloud_set_meta_struct (canvas->priv->cloud, canvas->priv->mstruct);
 			break;
 		}
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
 		}
 	}
 }
@@ -195,12 +199,15 @@ browser_canvas_db_relations_get_property (GObject *object,
 		case PROP_META_STRUCT:
 			g_value_set_object (value, canvas->priv->mstruct);
 			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
 		}
 	}
 }
 
 static void
-cloud_object_selected_cb (ObjectsCloud *ocloud, ObjectsCloudObjType sel_type, 
+cloud_object_selected_cb (G_GNUC_UNUSED ObjectsCloud *ocloud, G_GNUC_UNUSED ObjectsCloudObjType sel_type,
 			  const gchar *sel_contents, BrowserCanvasDbRelations *dbrel)
 {
 	GdaMetaTable *mtable;
@@ -313,7 +320,7 @@ canvas_entity_popup_func (BrowserCanvasTable *ce)
 }
 
 static void
-popup_func_delete_cb (GtkMenuItem *mitem, BrowserCanvasTable *ce)
+popup_func_delete_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvasTable *ce)
 {
 	GdaMetaTable *mtable;
 	BrowserCanvasDbRelations *dbrel;
@@ -351,7 +358,7 @@ popup_func_delete_cb (GtkMenuItem *mitem, BrowserCanvasTable *ce)
 }
 
 static void
-popup_func_add_depend_cb (GtkMenuItem *mitem, BrowserCanvasTable *ce)
+popup_func_add_depend_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvasTable *ce)
 {
 	BrowserCanvasDbRelations *dbrel;
 	GdaMetaDbObject *dbo;
@@ -387,7 +394,7 @@ popup_func_add_depend_cb (GtkMenuItem *mitem, BrowserCanvasTable *ce)
 }
 
 static void
-popup_func_add_ref_cb (GtkMenuItem *mitem, BrowserCanvasTable *ce)
+popup_func_add_ref_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvasTable *ce)
 {
 	BrowserCanvasDbRelations *dbrel;
 	GdaMetaDbObject *dbo;
@@ -511,14 +518,14 @@ build_context_menu (BrowserCanvas *canvas)
 }
 
 static gboolean
-add_dialog_delete_event (GtkWidget *dialog, GdkEvent *event, gpointer data)
+add_dialog_delete_event (GtkWidget *dialog, G_GNUC_UNUSED GdkEvent *event, G_GNUC_UNUSED gpointer data)
 {
 	gtk_widget_hide (dialog);
 	return TRUE;
 }
 
 static void
-popup_add_table_cb (GtkMenuItem *mitem, BrowserCanvasDbRelations *dbrels)
+popup_add_table_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvasDbRelations *dbrels)
 {
 	if (! dbrels->priv->add_dialog) {
 		GtkWidget *vbox, *cloud, *find, *dcontents;
