@@ -29,6 +29,8 @@
 #include "../common/ui-formgrid.h"
 
 #include "data-source.h"
+#define DEFAULT_DATA_SOURCE_NAME "DataSource"
+#define DEPENDENCY_SEPARATOR "<|>"
 
 /* signals */
 enum {
@@ -48,6 +50,7 @@ static void data_source_init (DataSource *source);
 static void data_source_dispose (GObject *object);
 
 
+static void update_export_information (DataSource *source);
 static void compute_stmt_and_params (DataSource *source);
 static void compute_import_params (DataSource *source);
 
@@ -55,6 +58,75 @@ static void compute_import_params (DataSource *source);
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass  *parent_class = NULL;
 
+typedef struct {
+	gchar *dep_id;
+	gchar *dep_table;
+	gchar *dep_columns; /* column names, separated by a |, sorted */
+} Dependency;
+
+static void
+dependency_free (Dependency *dep)
+{
+	g_free (dep->dep_id);
+	g_free (dep->dep_table);
+	g_free (dep->dep_columns);
+	g_free (dep);
+}
+
+/*
+ * converts an array of column names into a single string in the format:
+ * <colname>[SEP<colname>...] where SEP is DEPENDENCY_SEPARATOR
+ * 
+ * Returns: a new string, never %NULL
+ */
+static gchar *
+column_names_to_string (gint size, const gchar **colnames)
+{
+	if (!colnames)
+		return g_strdup ("");
+
+	GString *string = NULL;
+	GArray *colsarray;
+	gint i;
+	colsarray = g_array_new (FALSE, FALSE, sizeof (gchar*));
+	for (i = 0; i < size; i++)
+		g_array_append_val (colsarray, colnames[i]);
+	g_array_sort (colsarray, (GCompareFunc) g_strcmp0);
+	for (i = 0; i < size; i++) {
+		gchar *tmp;
+		tmp = g_array_index (colsarray, gchar *, i);
+		if (!string)
+			string = g_string_new (tmp);
+		else {
+			g_string_append (string, DEPENDENCY_SEPARATOR);
+			g_string_append (string, tmp);
+		}
+	}
+	g_array_free (colsarray, TRUE);
+	return g_string_free (string, FALSE);
+}
+
+static Dependency *
+dependency_find (GSList *dep_list, const gchar *id, const gchar *table, gint size, const gchar **colnames)
+{
+	GSList *list;
+	gchar *colsstring = NULL;
+	for (list = dep_list; list; list = list->next) {
+		Dependency *dep = (Dependency*) list->data;
+		if (strcmp (dep->dep_id, id) || strcmp (dep->dep_table, table))
+			continue;
+
+		if (!colsstring)
+			colsstring = column_names_to_string (size, colnames);
+		if (!strcmp (colsstring, dep->dep_columns)) {
+			g_free (colsstring);
+			return dep;
+		}
+	}
+	g_free (colsstring);
+	return NULL;
+}
+
 struct _DataSourcePrivate {
 	BrowserConnection *bcnc;
 	gchar             *title;
@@ -72,7 +144,7 @@ struct _DataSourcePrivate {
 
 	gchar             *tablename;
 	GdaSqlBuilder     *builder;
-	GSList            *dependencies; /* list of strings of table name or ID */
+	GSList            *dependencies; /* list of Dependency pointers */
 
 	GdaStatement      *stmt;
 	GdaSet            *ext_params; /* "free" parameters */
@@ -100,7 +172,8 @@ data_source_get_type (void)
 			NULL,
 			sizeof (DataSource),
 			0,
-			(GInstanceInitFunc) data_source_init
+			(GInstanceInitFunc) data_source_init,
+			0
 		};
 
 		
@@ -151,6 +224,7 @@ static void
 data_source_init (DataSource *source)
 {
 	source->priv = g_new0 (DataSourcePrivate, 1);
+	source->priv->id = g_strdup (DEFAULT_DATA_SOURCE_NAME);
 	source->priv->bcnc = NULL;
 	source->priv->source_type = DATA_SOURCE_UNKNOWN;
 	source->priv->need_rerun = FALSE;
@@ -160,13 +234,13 @@ data_source_init (DataSource *source)
 }
 
 static void
-params_changed_cb (GdaSet *params, GdaHolder *holder, DataSource *source)
+params_changed_cb (G_GNUC_UNUSED GdaSet *params, G_GNUC_UNUSED GdaHolder *holder, DataSource *source)
 {
 	source->priv->need_rerun = TRUE;
 }
 
 static void
-ext_params_changed_cb (GdaSet *params, GdaHolder *holder, DataSource *source)
+ext_params_changed_cb (G_GNUC_UNUSED GdaSet *params, G_GNUC_UNUSED GdaHolder *holder, DataSource *source)
 {
 #ifdef DEBUG_SOURCE
 	g_print ("  => data source [%s] should rerun\n",
@@ -209,7 +283,7 @@ data_source_reset (DataSource *source)
 	}
 	
 	if (source->priv->dependencies) {
-		g_slist_foreach (source->priv->dependencies, (GFunc) g_free, NULL);
+		g_slist_foreach (source->priv->dependencies, (GFunc) dependency_free, NULL);
 		g_slist_free (source->priv->dependencies);
 		source->priv->dependencies = NULL;
 	}
@@ -275,7 +349,6 @@ data_source_new (BrowserConnection *bcnc, DataSourceType type)
 	source = DATA_SOURCE (g_object_new (DATA_SOURCE_TYPE, NULL));
 	source->priv->bcnc = g_object_ref (bcnc);
 	source->priv->source_type = type;
-	source->priv->id = g_strdup ("NewSource");
 
 	return source;
 }
@@ -303,11 +376,13 @@ data_source_new_from_xml_node (BrowserConnection *bcnc, xmlNodePtr node, GError
 	xmlChar *prop;
 	prop = xmlGetProp (node, BAD_CAST "title");
 	if (prop) {
+		g_free (source->priv->title);
 		source->priv->title = g_strdup ((gchar*) prop);
 		xmlFree (prop);
 	}
 	prop = xmlGetProp (node, BAD_CAST "id");
 	if (prop) {
+		g_free (source->priv->id);
 		source->priv->id = g_strdup ((gchar*) prop);
 		xmlFree (prop);
 	}
@@ -417,14 +492,42 @@ init_from_table_node (DataSource *source, xmlNodePtr node, GError **error)
 	for (subnode = node->children; subnode; subnode = subnode->next) {
 		if (!strcmp ((gchar*)subnode->name, "depend")) {
 			xmlChar *fk_table, *id;
+			GArray *cols_array = NULL;
+			xmlNodePtr chnode;
 			
 			fk_table = xmlGetProp (subnode, BAD_CAST "foreign_key_table");
 			id = xmlGetProp (subnode, BAD_CAST "id");
+			for (chnode = subnode->children; chnode; chnode = chnode->next) {
+				xmlChar *colname;
+				if (strcmp ((gchar*)chnode->name, "column"))
+					continue;
+				colname = xmlNodeGetContent (chnode);
+				if (colname) {
+					if (! cols_array)
+						cols_array = g_array_new (FALSE, FALSE, sizeof (gchar*));
+					g_array_append_val (cols_array, colname);
+				}
+			}
 
-			data_source_add_dependendency (source, (gchar *) fk_table, (gchar*) id, error);
-			xmlFree (fk_table);
+			if (fk_table &&
+			    ! data_source_add_dependency (source, (gchar *) fk_table, (gchar*) id,
+							  cols_array ? cols_array->len : 0,
+							  (const gchar **) (cols_array ? cols_array->data : NULL),
+							  error))
+				retval = FALSE;
+			if (fk_table)
+				xmlFree (fk_table);
 			if (id)
 				xmlFree (id);
+			if (cols_array) {
+				gsize i;
+				for (i = 0; i < cols_array->len; i++) {
+					xmlChar *colname;
+					colname = g_array_index (cols_array, xmlChar*, i);
+					xmlFree (colname);
+				}
+				g_array_free (cols_array, TRUE);
+			}
 			break;
 		}
 	}
@@ -433,23 +536,27 @@ init_from_table_node (DataSource *source, xmlNodePtr node, GError **error)
 }
 
 /**
- * data_source_add_dependendency
+ * data_source_add_dependency
  * @source: a #DataSource
  * @table: the name of the referenced table
  * @id: the ID of the referenced data source, or %NULL if its ID is the same as the table name
+ * @col_name_size: the size of @col_names
+ * @col_names: names of the FK columns involved in the foreign key, or %NULL
+ * @error: a place to store errors, or %NULL
  *
  * Adds a dependency on the @table table, only for DATA_SOURCE_TABLE sources
  */
 gboolean
-data_source_add_dependendency (DataSource *source, const gchar *table,
-			       const char *id, GError **error)
+data_source_add_dependency (DataSource *source, const gchar *table,
+			    const char *id, gint col_name_size, const gchar **col_names,
+			    GError **error)
 {
 	g_return_val_if_fail (IS_DATA_SOURCE (source), FALSE);
 	g_return_val_if_fail (table && *table, FALSE);
 	g_return_val_if_fail (source->priv->source_type == DATA_SOURCE_TABLE, FALSE);
 	g_return_val_if_fail (source->priv->builder, FALSE);
 
-	if (g_slist_find (source->priv->dependencies, id ? id : table))
+	if (dependency_find (source->priv->dependencies, id ? id : table, table, col_name_size, col_names))
 		return TRUE;
 
 	GdaMetaTable *mtable, *mlinked;
@@ -464,10 +571,51 @@ data_source_add_dependendency (DataSource *source, const gchar *table,
 	/* find foreign key to linked table */
 	GdaMetaTableForeignKey *fk = NULL;
 	GSList *list;
+	gboolean reverse = FALSE;
 	for (list = mtable->fk_list; list; list = list->next) {
 		if (GDA_META_TABLE_FOREIGN_KEY (list->data)->depend_on == GDA_META_DB_OBJECT (mlinked)) {
 			fk = GDA_META_TABLE_FOREIGN_KEY (list->data);
-			break;
+			if (col_names && (col_name_size == fk->cols_nb)) {
+				gint i;
+				for (i = 0; i < col_name_size; i++) {
+					gint j;
+					for (j = 0; j < col_name_size; j++) {
+						if (!strcmp (col_names [i], fk->fk_names_array [j]))
+							break;
+					}
+					if (j == col_name_size) {
+						fk = NULL; /* not this FK */
+						break;
+					}
+				}
+			}
+			if (fk)
+				break;
+		}
+	}
+	if (!fk) {
+		for (list = mlinked->fk_list; list; list = list->next) {
+			if (GDA_META_TABLE_FOREIGN_KEY (list->data)->depend_on == GDA_META_DB_OBJECT (mtable)) {
+				fk = GDA_META_TABLE_FOREIGN_KEY (list->data);
+				reverse = TRUE;
+				if (col_names && (col_name_size == fk->cols_nb)) {
+					gint i;
+					for (i = 0; i < col_name_size; i++) {
+						gint j;
+						for (j = 0; j < col_name_size; j++) {
+							if (!strcmp (col_names [i],
+								     fk->fk_names_array [j]))
+								break;
+						}
+						if (j == col_name_size) {
+							fk = NULL; /* not this FK */
+							break;
+						}
+					}
+				}
+				if (fk)
+					break;
+			}
 		}
 	}
 	if (!fk) {
@@ -484,19 +632,33 @@ data_source_add_dependendency (DataSource *source, const gchar *table,
 	else if (fk->cols_nb == 1) {
 		gchar *tmp;
 		GdaMetaTableColumn *col;
-		const GdaSqlBuilderId id1 = gda_sql_builder_add_id (source->priv->builder,
-								    fk->fk_names_array [0]);
-		tmp = g_strdup_printf ("%s@%s", id ? id : table, fk->ref_pk_names_array [0]);
-		
-		col = GDA_META_TABLE_COLUMN (g_slist_nth_data (mlinked->columns,
-							       fk->ref_pk_cols_array [0] - 1));
-		g_assert (col);
-		const GdaSqlBuilderId id2 = gda_sql_builder_add_param (source->priv->builder, tmp,
-								       col->gtype, FALSE);
-		g_free (tmp);
-		const GdaSqlBuilderId id_cond = gda_sql_builder_add_cond (source->priv->builder,
-									  GDA_SQL_OPERATOR_TYPE_EQ,
-									  id1, id2, 0);
+		GdaSqlBuilderId id1, id2, id_cond;
+		if (reverse) {
+			id1 = gda_sql_builder_add_id (source->priv->builder, fk->ref_pk_names_array [0]);
+			tmp = g_strdup_printf ("%s@%s", id ? id : table, fk->fk_names_array [0]);
+
+			col = GDA_META_TABLE_COLUMN (g_slist_nth_data (mlinked->columns,
+								       fk->fk_cols_array [0] - 1));
+			g_assert (col);
+			id2 = gda_sql_builder_add_param (source->priv->builder, tmp, col->gtype, FALSE);
+			g_free (tmp);
+		}
+		else {
+			id1 = gda_sql_builder_add_id (source->priv->builder, fk->fk_names_array [0]);
+			tmp = g_strdup_printf ("%s@%s", id ? id : table, fk->ref_pk_names_array [0]);
+			
+			col = GDA_META_TABLE_COLUMN (g_slist_nth_data (mlinked->columns,
+								       fk->ref_pk_cols_array [0] - 1));
+			g_assert (col);
+			id2 = gda_sql_builder_add_param (source->priv->builder, tmp, col->gtype, FALSE);
+			g_free (tmp);
+			id_cond = gda_sql_builder_add_cond (source->priv->builder,
+							    GDA_SQL_OPERATOR_TYPE_EQ,
+							    id1, id2, 0);
+		}
+		id_cond = gda_sql_builder_add_cond (source->priv->builder,
+						    GDA_SQL_OPERATOR_TYPE_EQ,
+						    id1, id2, 0);
 		gda_sql_builder_set_where (source->priv->builder, id_cond);
 	}
 	else {
@@ -505,20 +667,32 @@ data_source_add_dependendency (DataSource *source, const gchar *table,
 		GdaMetaTableColumn *col;
 		GdaSqlBuilderId andid;
 		GdaSqlBuilderId *op_ids;
+		GdaSqlBuilderId id1, id2;
 		op_ids = g_new (GdaSqlBuilderId, fk->cols_nb);
 		
 		for (i = 0; i < fk->cols_nb; i++) {
-			const GdaSqlBuilderId id1 = gda_sql_builder_add_id (source->priv->builder,
-									    fk->fk_names_array [i]);
-			tmp = g_strdup_printf ("%s@%s", id ? id : table, fk->ref_pk_names_array [i]);
-			
-			col = GDA_META_TABLE_COLUMN (g_slist_nth_data (mlinked->columns,
-								       fk->ref_pk_cols_array [i] - 1));
-			g_assert (col);
-			const GdaSqlBuilderId id2 = gda_sql_builder_add_param (source->priv->builder,
-									       tmp, col->gtype, FALSE);
-			g_free (tmp);
-			op_ids [i] = gda_sql_builder_add_cond (source->priv->builder, GDA_SQL_OPERATOR_TYPE_EQ,
+			if (reverse) {
+				id1 = gda_sql_builder_add_id (source->priv->builder, fk->ref_pk_names_array [i]);
+				tmp = g_strdup_printf ("%s@%s", id ? id : table, fk->fk_names_array [i]);
+
+				col = GDA_META_TABLE_COLUMN (g_slist_nth_data (mlinked->columns,
+									       fk->fk_cols_array [i] - 1));
+				g_assert (col);
+				id2 = gda_sql_builder_add_param (source->priv->builder, tmp, col->gtype, FALSE);
+				g_free (tmp);
+			}
+			else {
+				id1 = gda_sql_builder_add_id (source->priv->builder, fk->fk_names_array [i]);
+				tmp = g_strdup_printf ("%s@%s", id ? id : table, fk->ref_pk_names_array [i]);
+				
+				col = GDA_META_TABLE_COLUMN (g_slist_nth_data (mlinked->columns,
+									       fk->ref_pk_cols_array [i] - 1));
+				g_assert (col);
+				id2 = gda_sql_builder_add_param (source->priv->builder, tmp, col->gtype, FALSE);
+				g_free (tmp);
+			}
+			op_ids [i] = gda_sql_builder_add_cond (source->priv->builder,
+							       GDA_SQL_OPERATOR_TYPE_EQ,
 							       id1, id2, 0);
 		}
 		andid = gda_sql_builder_add_cond_v (source->priv->builder, GDA_SQL_OPERATOR_TYPE_AND,
@@ -527,7 +701,11 @@ data_source_add_dependendency (DataSource *source, const gchar *table,
 		gda_sql_builder_set_where (source->priv->builder, andid);
 	}
 
-	source->priv->dependencies = g_slist_append (source->priv->dependencies, g_strdup (id ? id : table));
+	Dependency *dep = g_new0 (Dependency, 1);
+	dep->dep_id = g_strdup (id ? id : table);
+	dep->dep_table = g_strdup (table);
+	dep->dep_columns = column_names_to_string (col_name_size, col_names);
+	source->priv->dependencies = g_slist_append (source->priv->dependencies, dep);
 
 	compute_stmt_and_params (source);
 	return TRUE;
@@ -545,7 +723,7 @@ data_source_to_xml_node (DataSource *source)
 	switch (source->priv->source_type) {
 	case DATA_SOURCE_TABLE:
 		node = xmlNewNode (NULL, BAD_CAST "table");
-		if (source->priv->id && g_strcmp0 (source->priv->id, source->priv->tablename))
+		if (g_strcmp0 (source->priv->id, source->priv->tablename))
 			xmlSetProp (node, BAD_CAST "id", BAD_CAST source->priv->id);
 		if (source->priv->title && g_strcmp0 (source->priv->title, source->priv->tablename))
 			xmlSetProp (node, BAD_CAST "title", BAD_CAST source->priv->title);
@@ -555,17 +733,26 @@ data_source_to_xml_node (DataSource *source)
 		if (source->priv->dependencies) {
 			GSList *list;
 			for (list = source->priv->dependencies; list; list = list->next) {
+				Dependency *dep = (Dependency*) list->data;
 				xmlNodePtr depnode;
 				depnode = xmlNewChild (node, NULL, BAD_CAST "depend", NULL);
 				xmlSetProp (depnode, BAD_CAST "foreign_key_table",
-					    BAD_CAST (list->data));
+					    BAD_CAST (dep->dep_table));
+				xmlSetProp (depnode, BAD_CAST "id",
+					    BAD_CAST (dep->dep_id));
+
+				gchar **array;
+				gint i;
+				array = g_strsplit (dep->dep_columns, DEPENDENCY_SEPARATOR, 0);
+				for (i = 0; array[i]; i++)
+					xmlNewChild (depnode, NULL, BAD_CAST "column", BAD_CAST (array[i]));
+				g_strfreev (array);
 			}
 		}
 		break;
 	case DATA_SOURCE_SELECT: {
 		node = xmlNewNode (NULL, BAD_CAST "query");
-		if (source->priv->id)
-			xmlSetProp (node, BAD_CAST "id", BAD_CAST source->priv->id);
+		xmlSetProp (node, BAD_CAST "id", BAD_CAST source->priv->id);
 		if (source->priv->title)
 			xmlSetProp (node, BAD_CAST "title", BAD_CAST source->priv->title);
 
@@ -699,7 +886,7 @@ data_source_set_params (DataSource *source, GdaSet *params)
 			GdaHolder *bind = NULL;
 			if (params)
 				bind = gda_set_get_holder (params, gda_holder_get_id (holder));
-			if (gda_holder_set_bind (holder, bind, NULL))
+			if ((holder != bind) && gda_holder_set_bind (holder, bind, NULL))
 				bound = TRUE;
 		}
 	}
@@ -714,7 +901,7 @@ data_source_set_params (DataSource *source, GdaSet *params)
 /**
  * data_source_get_export_names
  *
- * Returns: an array of strings, or %NULL
+ * Returns: an array of strings (don't modify) or %NULL
  */
 GArray *
 data_source_get_export_names (DataSource *source)
@@ -875,7 +1062,7 @@ data_source_create_grid (DataSource *source)
 /**
  * data_source_set_id
  * @source: a #DataSource
- * @id: the new source's ID
+ * @id: the new source's ID, not %NULL
  *
  * @source MUST NOT be executed when calling this method.
  */
@@ -884,10 +1071,11 @@ data_source_set_id (DataSource *source, const gchar * id)
 {
 	g_return_if_fail (IS_DATA_SOURCE (source));
 	g_return_if_fail (! data_source_execution_going_on (source));
+	g_return_if_fail (id && *id);
 
 	g_free (source->priv->id);
-	if (id)
-		source->priv->id = g_strdup (id);
+	source->priv->id = g_strdup (id);
+	update_export_information (source);
 	g_signal_emit (source, data_source_signals [CHANGED], 0);
 }
 
@@ -922,6 +1110,8 @@ data_source_set_title (DataSource *source, const gchar * title)
 	g_free (source->priv->title);
 	if (title)
 		source->priv->title = g_strdup (title);
+	else
+		source->priv->title = NULL;
 	g_signal_emit (source, data_source_signals [CHANGED], 0);
 }
 
@@ -938,10 +1128,75 @@ data_source_get_title (DataSource *source)
 		return source->priv->title;
 	else if (source->priv->impl_title)
 		return source->priv->impl_title;
-	else if (source->priv->id)
-		return source->priv->id;
 	else
-		return _("No name");
+		return source->priv->id;
+}
+
+static void
+update_export_information (DataSource *source)
+{
+	g_assert (source->priv->id);
+
+	/* clear previous information */
+	if (source->priv->export_names) {
+		g_array_free (source->priv->export_names, TRUE);
+		source->priv->export_names = NULL;
+	}
+	if (source->priv->export_columns) {
+		g_hash_table_destroy (source->priv->export_columns);
+		source->priv->export_columns = NULL;
+	}
+
+	if (! source->priv->stmt)
+		return;
+
+	/* Get GdaSqlStatement */
+	GdaSqlStatement *sqlst;
+	g_object_get ((GObject*) source->priv->stmt, "structure", &sqlst, NULL);
+	if (browser_connection_check_sql_statement_validify (source->priv->bcnc, sqlst, NULL))
+		g_object_set ((GObject*) source->priv->stmt, "structure", sqlst, NULL);
+	if (! sqlst)
+		return;
+
+	/* compute exported data */
+	if (sqlst->stmt_type == GDA_SQL_STATEMENT_SELECT) {
+		GdaSqlStatementSelect *selst;
+		selst = (GdaSqlStatementSelect*) sqlst->contents;
+		GSList *list;
+		gint i;
+		for (i = 0, list = selst->expr_list; list; i++, list = list->next) {
+			gchar *tmp;
+			if (! source->priv->export_names)
+				source->priv->export_names = g_array_new (FALSE, FALSE,
+									  sizeof (gchar*));
+			if (! source->priv->export_columns)
+				source->priv->export_columns =
+					g_hash_table_new_full (g_str_hash, g_str_equal,
+							       g_free, NULL);
+			
+			tmp = g_strdup_printf ("%s@%d", source->priv->id, i+1);
+			g_array_append_val (source->priv->export_names, tmp);
+			g_hash_table_insert (source->priv->export_columns, tmp,
+					     GINT_TO_POINTER (i + 1));
+#ifdef DEBUG_SOURCE
+			g_print ("\tEXPORT [%s]\n", tmp);
+#endif
+			
+			GdaSqlSelectField *sf = (GdaSqlSelectField *) list->data;
+			if (sf->validity_meta_table_column) {
+				tmp = g_strdup_printf ("%s@%s", source->priv->id,
+						       sf->validity_meta_table_column->column_name);
+				g_array_append_val (source->priv->export_names, tmp);
+				g_hash_table_insert (source->priv->export_columns, tmp,
+						     GINT_TO_POINTER (i + 1));
+#ifdef DEBUG_SOURCE
+				g_print ("\tEXPORT [%s]\n", tmp);
+#endif
+			}
+		}
+	}
+
+	gda_sql_statement_free (sqlst);
 }
 
 /**
@@ -968,16 +1223,18 @@ data_source_set_table (DataSource *source, const gchar *table, GError **error)
 	source->priv->source_type = DATA_SOURCE_TABLE;
 	source->priv->tablename = g_strdup (table);
 
+	if (! strcmp (source->priv->id, DEFAULT_DATA_SOURCE_NAME)) {
+		g_free (source->priv->id);
+		source->priv->id = g_strdup (table);
+	}
+
 	g_free (source->priv->impl_title);
 	source->priv->impl_title = g_strdup_printf (_("Contents of '%s'"), table);
 
-	g_free (source->priv->id);
-	source->priv->id = g_strdup ((gchar*) table);
-
 	/* build statement */
-	GSList *list;
 	GdaSqlBuilder *b;
 	gint i;
+	GSList *list;
 
 	b = gda_sql_builder_new (GDA_SQL_STATEMENT_SELECT);
 	source->priv->builder = b;
@@ -990,7 +1247,6 @@ data_source_set_table (DataSource *source, const gchar *table, GError **error)
 					  gda_sql_builder_add_expr (b, NULL,
 								    G_TYPE_INT, DEFAULT_DATA_SELECT_LIMIT),
 					  0);
-
 	for (i = 0, list = mtable->columns; list; i++, list = list->next) {
 		GdaMetaTableColumn *mcol;
 		mcol = GDA_META_TABLE_COLUMN (list->data);
@@ -1003,43 +1259,14 @@ data_source_set_table (DataSource *source, const gchar *table, GError **error)
 										 mcol->column_name),
 							 FALSE, NULL);
 		}
-
-		/* export value */
-		gchar *tmp;
-		if (source->priv->id)
-			tmp = g_strdup_printf ("%s@%s", source->priv->id, mcol->column_name);
-		else
-			tmp = g_strdup_printf ("%s@%s", table, mcol->column_name);
-		if (! source->priv->export_names)
-			source->priv->export_names = g_array_new (FALSE, FALSE,
-								  sizeof (gchar*));
-		if (! source->priv->export_columns)
-			source->priv->export_columns =
-				g_hash_table_new_full (g_str_hash, g_str_equal,
-						       g_free, NULL);
-		g_array_append_val (source->priv->export_names, tmp);
-		g_hash_table_insert (source->priv->export_columns, tmp,
-				     GINT_TO_POINTER (i + 1));
-#ifdef DEBUG_SOURCE
-		g_print ("\tEXPORT [%s]\n", tmp);
-#endif
-
-		if (source->priv->id)
-			tmp = g_strdup_printf ("%s@%d", source->priv->id, i + 1);
-		else
-			tmp = g_strdup_printf ("%s@%d", table, i + 1);
-		g_array_append_val (source->priv->export_names, tmp);
-		g_hash_table_insert (source->priv->export_columns, tmp,
-				     GINT_TO_POINTER (i + 1));
-#ifdef DEBUG_SOURCE
-		g_print ("\tEXPORT [%s]\n", tmp);
-#endif
 	}
 
 	/* compute statement & parameters */
 	compute_stmt_and_params (source);
 	/*g_print ("SQL [%s]\n", gda_statement_to_sql (source->priv->stmt, NULL, NULL));*/
 
+	update_export_information (source);
+
 #ifdef DEBUG_SOURCE
 	g_print ("\n");
 #endif
@@ -1087,48 +1314,10 @@ data_source_set_query (DataSource *source, const gchar *sql, GError **warning)
 	g_object_get ((GObject*) source->priv->stmt, "structure", &sqlst, NULL);
 	if (browser_connection_normalize_sql_statement (source->priv->bcnc, sqlst, NULL))
 		g_object_set ((GObject*) source->priv->stmt, "structure", sqlst, NULL);
-	
-	/* compute export data */
-	if (source->priv->id) {
-		if (sqlst->stmt_type == GDA_SQL_STATEMENT_SELECT) {
-			GdaSqlStatementSelect *selst;
-			selst = (GdaSqlStatementSelect*) sqlst->contents;
-			GSList *list;
-			gint i;
-			for (i = 0, list = selst->expr_list; list; i++, list = list->next) {
-				gchar *tmp;
-				if (! source->priv->export_names)
-					source->priv->export_names = g_array_new (FALSE, FALSE,
-										  sizeof (gchar*));
-				if (! source->priv->export_columns)
-					source->priv->export_columns =
-						g_hash_table_new_full (g_str_hash, g_str_equal,
-								       g_free, NULL);
-				
-				tmp = g_strdup_printf ("%s@%d", source->priv->id, i+1);
-				g_array_append_val (source->priv->export_names, tmp);
-				g_hash_table_insert (source->priv->export_columns, tmp,
-						     GINT_TO_POINTER (i + 1));
-#ifdef DEBUG_SOURCE
-				g_print ("\tEXPORT [%s]\n", tmp);
-#endif
-				
-				GdaSqlSelectField *sf = (GdaSqlSelectField *) list->data;
-				if (sf->validity_meta_table_column) {
-					tmp = g_strdup_printf ("%s@%s", source->priv->id,
-							       sf->validity_meta_table_column->column_name);
-					g_array_append_val (source->priv->export_names, tmp);
-					g_hash_table_insert (source->priv->export_columns, tmp,
-							     GINT_TO_POINTER (i + 1));
-#ifdef DEBUG_SOURCE
-					g_print ("\tEXPORT [%s]\n", tmp);
-#endif
-				}
-			}
-		}
-	}
 	gda_sql_statement_free (sqlst);
 	
+	update_export_information (source);
+	
 	/* compute parameters */
 	source->priv->need_rerun = FALSE;
 	compute_import_params (source);
@@ -1148,6 +1337,13 @@ compute_stmt_and_params (DataSource *source)
 		g_object_unref (source->priv->stmt);
 	source->priv->stmt = gda_sql_builder_get_statement (source->priv->builder, NULL);
 	compute_import_params (source);
+
+#ifdef DEBUG_SOURCE
+	gchar *sql;
+	sql = gda_statement_to_sql (source->priv->stmt, NULL, NULL);
+	g_print ("[%s]\n", sql);
+	g_free (sql);
+#endif
 }
 
 static void
