@@ -83,7 +83,7 @@ mgr_favorites_class_init (MgrFavoritesClass *klass)
 }
 
 static void
-mgr_favorites_init (MgrFavorites *mgr, MgrFavoritesClass *klass)
+mgr_favorites_init (MgrFavorites *mgr, G_GNUC_UNUSED MgrFavoritesClass *klass)
 {
 	mgr->priv = g_new0 (MgrFavoritesPriv, 1);
 }
@@ -126,7 +126,8 @@ mgr_favorites_get_type (void)
                         NULL,
                         sizeof (MgrFavorites),
                         0,
-                        (GInstanceInitFunc) mgr_favorites_init
+                        (GInstanceInitFunc) mgr_favorites_init,
+			0
                 };
 
                 g_static_mutex_lock (&registering);
@@ -154,6 +155,9 @@ mgr_favorites_set_property (GObject *object,
 				g_object_ref (mgr->priv->bcnc);
 			
 			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
                 }
         }
 }
@@ -172,6 +176,9 @@ mgr_favorites_get_property (GObject *object,
 		case PROP_BROWSER_CNC:
 			g_value_set_object (value, mgr->priv->bcnc);
 			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
                 }
         }
 }
